@@ -29,6 +29,9 @@ class TioneClient(AbstractClient):
     def ChatCompletion(self, request):
         """该接口支持与自行部署的大模型的聊天。
 
+        使用该接口调用时需要携带腾讯云的密钥信息用于身份信息鉴权，建议通过腾讯云的云 API SDK调用，具体可以参考
+        https://cloud.tencent.com/document/product/1278/85305
+
         :param request: Request instance for ChatCompletion.
         :type request: :class:`tencentcloud.tione.v20211111.models.ChatCompletionRequest`
         :rtype: :class:`tencentcloud.tione.v20211111.models.ChatCompletionResponse`
